"""
@author: Stefan Lehmann

"""

import os

W1_DEVICE_DIRECTORY = "/sys/bus/w1/devices"

class W1Bus():
    """
    Class for accessing the onewire bus of the Raspberry Pi

    @type devices: list
    @ivar devices: list of the connected devices, the index is the device id
    """
    def __init__(self):
        self.devices = os.listdir(W1_DEVICE_DIRECTORY)

    def filename(self, device_id):
        """
        Return the filename of the given sensor.
        @rtype: str
        """
        path_ = os.path.join(W1_DEVICE_DIRECTORY, self.devices[device_id])
        path_ = os.path.join(path_, "w1_slave")
        return path_

    def read_value(self, device_id):
        """
        Return the temperature of the sensor with the given id.
        @type device_id: int
        @param device_id: sensor id in the device list
        @rtype: float

        """

        with open(self.filename(device_id)) as f:
            text = f.read()
            second_line = text.split("\n")[1]
            temperature_data = second_line.split(" ")[9]
            temperature = float(temperature_data[2:]) / 1000.0
            return temperature

os.system('sudo modprobe w1-gpio')
os.system('sudo modprobe w1-therm')